package nfsconv

import "go.opentelemetry.io/otel/semconv/v1.38.0/nfsconv"

Package nfsconv provides types and functionality for OpenTelemetry semantic conventions in the "nfs" namespace.

Index

Types

type ClientNetCount

type ClientNetCount struct {
	metric.Int64Counter
}

ClientNetCount is an instrument used to record metric values conforming to the "nfs.client.net.count" semantic conventions. It represents the reports the count of kernel NFS client TCP segments and UDP datagrams handled.

func NewClientNetCount

func NewClientNetCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientNetCount, error)

NewClientNetCount returns a new ClientNetCount instrument.

func (ClientNetCount) Add

func (m ClientNetCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

Linux: this metric is taken from the Linux kernel's svc_stat.netudpcnt and svc_stat.nettcpcnt

func (ClientNetCount) AddSet

func (m ClientNetCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.netudpcnt and svc_stat.nettcpcnt

func (ClientNetCount) AttrNetworkTransport

func (ClientNetCount) AttrNetworkTransport(val NetworkTransportAttr) attribute.KeyValue

AttrNetworkTransport returns an optional attribute for the "network.transport" semantic convention. It represents the OSI transport layer or inter-process communication method.

func (ClientNetCount) Description

func (ClientNetCount) Description() string

Description returns the semantic convention description of the instrument

func (ClientNetCount) Inst

Inst returns the underlying metric instrument.

func (ClientNetCount) Name

func (ClientNetCount) Name() string

Name returns the semantic convention name of the instrument.

func (ClientNetCount) Unit

func (ClientNetCount) Unit() string

Unit returns the semantic convention unit of the instrument

type ClientNetTCPConnectionAccepted

type ClientNetTCPConnectionAccepted struct {
	metric.Int64Counter
}

ClientNetTCPConnectionAccepted is an instrument used to record metric values conforming to the "nfs.client.net.tcp.connection.accepted" semantic conventions. It represents the reports the count of kernel NFS client TCP connections accepted.

func NewClientNetTCPConnectionAccepted

func NewClientNetTCPConnectionAccepted(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientNetTCPConnectionAccepted, error)

NewClientNetTCPConnectionAccepted returns a new ClientNetTCPConnectionAccepted instrument.

func (ClientNetTCPConnectionAccepted) Add

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpconn

func (ClientNetTCPConnectionAccepted) AddSet

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpconn

func (ClientNetTCPConnectionAccepted) Description

func (ClientNetTCPConnectionAccepted) Description() string

Description returns the semantic convention description of the instrument

func (ClientNetTCPConnectionAccepted) Inst

Inst returns the underlying metric instrument.

func (ClientNetTCPConnectionAccepted) Name

Name returns the semantic convention name of the instrument.

func (ClientNetTCPConnectionAccepted) Unit

Unit returns the semantic convention unit of the instrument

type ClientOperationCount

type ClientOperationCount struct {
	metric.Int64Counter
}

ClientOperationCount is an instrument used to record metric values conforming to the "nfs.client.operation.count" semantic conventions. It represents the reports the count of kernel NFSv4+ client operations.

func NewClientOperationCount

func NewClientOperationCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientOperationCount, error)

NewClientOperationCount returns a new ClientOperationCount instrument.

func (ClientOperationCount) Add

func (m ClientOperationCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

func (ClientOperationCount) AddSet

func (m ClientOperationCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

func (ClientOperationCount) AttrOncRPCVersion

func (ClientOperationCount) AttrOncRPCVersion(val int) attribute.KeyValue

AttrOncRPCVersion returns an optional attribute for the "onc_rpc.version" semantic convention. It represents the ONC/Sun RPC program version.

func (ClientOperationCount) AttrOperationName

func (ClientOperationCount) AttrOperationName(val string) attribute.KeyValue

AttrOperationName returns an optional attribute for the "nfs.operation.name" semantic convention. It represents the NFSv4+ operation name.

func (ClientOperationCount) Description

func (ClientOperationCount) Description() string

Description returns the semantic convention description of the instrument

func (ClientOperationCount) Inst

Inst returns the underlying metric instrument.

func (ClientOperationCount) Name

Name returns the semantic convention name of the instrument.

func (ClientOperationCount) Unit

Unit returns the semantic convention unit of the instrument

type ClientProcedureCount

type ClientProcedureCount struct {
	metric.Int64Counter
}

ClientProcedureCount is an instrument used to record metric values conforming to the "nfs.client.procedure.count" semantic conventions. It represents the reports the count of kernel NFS client procedures.

func NewClientProcedureCount

func NewClientProcedureCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientProcedureCount, error)

NewClientProcedureCount returns a new ClientProcedureCount instrument.

func (ClientProcedureCount) Add

func (m ClientProcedureCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

func (ClientProcedureCount) AddSet

func (m ClientProcedureCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

func (ClientProcedureCount) AttrOncRPCProcedureName

func (ClientProcedureCount) AttrOncRPCProcedureName(val string) attribute.KeyValue

AttrOncRPCProcedureName returns an optional attribute for the "onc_rpc.procedure.name" semantic convention. It represents the ONC/Sun RPC procedure name.

func (ClientProcedureCount) AttrOncRPCVersion

func (ClientProcedureCount) AttrOncRPCVersion(val int) attribute.KeyValue

AttrOncRPCVersion returns an optional attribute for the "onc_rpc.version" semantic convention. It represents the ONC/Sun RPC program version.

func (ClientProcedureCount) Description

func (ClientProcedureCount) Description() string

Description returns the semantic convention description of the instrument

func (ClientProcedureCount) Inst

Inst returns the underlying metric instrument.

func (ClientProcedureCount) Name

Name returns the semantic convention name of the instrument.

func (ClientProcedureCount) Unit

Unit returns the semantic convention unit of the instrument

type ClientRPCAuthrefreshCount

type ClientRPCAuthrefreshCount struct {
	metric.Int64Counter
}

ClientRPCAuthrefreshCount is an instrument used to record metric values conforming to the "nfs.client.rpc.authrefresh.count" semantic conventions. It represents the reports the count of kernel NFS client RPC authentication refreshes.

func NewClientRPCAuthrefreshCount

func NewClientRPCAuthrefreshCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientRPCAuthrefreshCount, error)

NewClientRPCAuthrefreshCount returns a new ClientRPCAuthrefreshCount instrument.

func (ClientRPCAuthrefreshCount) Add

func (m ClientRPCAuthrefreshCount) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel's svc_stat.rpcauthrefresh

func (ClientRPCAuthrefreshCount) AddSet

func (m ClientRPCAuthrefreshCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.rpcauthrefresh

func (ClientRPCAuthrefreshCount) Description

func (ClientRPCAuthrefreshCount) Description() string

Description returns the semantic convention description of the instrument

func (ClientRPCAuthrefreshCount) Inst

Inst returns the underlying metric instrument.

func (ClientRPCAuthrefreshCount) Name

Name returns the semantic convention name of the instrument.

func (ClientRPCAuthrefreshCount) Unit

Unit returns the semantic convention unit of the instrument

type ClientRPCCount

type ClientRPCCount struct {
	metric.Int64Counter
}

ClientRPCCount is an instrument used to record metric values conforming to the "nfs.client.rpc.count" semantic conventions. It represents the reports the count of kernel NFS client RPCs sent, regardless of whether they're accepted/rejected by the server.

func NewClientRPCCount

func NewClientRPCCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientRPCCount, error)

NewClientRPCCount returns a new ClientRPCCount instrument.

func (ClientRPCCount) Add

func (m ClientRPCCount) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel's svc_stat.rpccnt

func (ClientRPCCount) AddSet

func (m ClientRPCCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.rpccnt

func (ClientRPCCount) Description

func (ClientRPCCount) Description() string

Description returns the semantic convention description of the instrument

func (ClientRPCCount) Inst

Inst returns the underlying metric instrument.

func (ClientRPCCount) Name

func (ClientRPCCount) Name() string

Name returns the semantic convention name of the instrument.

func (ClientRPCCount) Unit

func (ClientRPCCount) Unit() string

Unit returns the semantic convention unit of the instrument

type ClientRPCRetransmitCount

type ClientRPCRetransmitCount struct {
	metric.Int64Counter
}

ClientRPCRetransmitCount is an instrument used to record metric values conforming to the "nfs.client.rpc.retransmit.count" semantic conventions. It represents the reports the count of kernel NFS client RPC retransmits.

func NewClientRPCRetransmitCount

func NewClientRPCRetransmitCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ClientRPCRetransmitCount, error)

NewClientRPCRetransmitCount returns a new ClientRPCRetransmitCount instrument.

func (ClientRPCRetransmitCount) Add

func (m ClientRPCRetransmitCount) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel's svc_stat.rpcretrans

func (ClientRPCRetransmitCount) AddSet

func (m ClientRPCRetransmitCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.rpcretrans

func (ClientRPCRetransmitCount) Description

func (ClientRPCRetransmitCount) Description() string

Description returns the semantic convention description of the instrument

func (ClientRPCRetransmitCount) Inst

Inst returns the underlying metric instrument.

func (ClientRPCRetransmitCount) Name

Name returns the semantic convention name of the instrument.

func (ClientRPCRetransmitCount) Unit

Unit returns the semantic convention unit of the instrument

type ErrorTypeAttr

type ErrorTypeAttr string

ErrorTypeAttr is an attribute conforming to the error.type semantic conventions. It represents the describes a class of error the operation ended with.

var (
	// ErrorTypeOther is a fallback error value to be used when the instrumentation
	// doesn't define a custom value.
	ErrorTypeOther ErrorTypeAttr = "_OTHER"
)

type NetworkIODirectionAttr

type NetworkIODirectionAttr string

NetworkIODirectionAttr is an attribute conforming to the network.io.direction semantic conventions. It represents the network IO operation direction.

var (
	// NetworkIODirectionTransmit is the standardized value "transmit" of
	// NetworkIODirectionAttr.
	NetworkIODirectionTransmit NetworkIODirectionAttr = "transmit"
	// NetworkIODirectionReceive is the standardized value "receive" of
	// NetworkIODirectionAttr.
	NetworkIODirectionReceive NetworkIODirectionAttr = "receive"
)

type NetworkTransportAttr

type NetworkTransportAttr string

NetworkTransportAttr is an attribute conforming to the network.transport semantic conventions. It represents the OSI transport layer or inter-process communication method.

var (
	// NetworkTransportTCP is the TCP.
	NetworkTransportTCP NetworkTransportAttr = "tcp"
	// NetworkTransportUDP is the UDP.
	NetworkTransportUDP NetworkTransportAttr = "udp"
	// NetworkTransportPipe is the named or anonymous pipe.
	NetworkTransportPipe NetworkTransportAttr = "pipe"
	// NetworkTransportUnix is the unix domain socket.
	NetworkTransportUnix NetworkTransportAttr = "unix"
	// NetworkTransportQUIC is the QUIC.
	NetworkTransportQUIC NetworkTransportAttr = "quic"
)

type ServerFhStaleCount

type ServerFhStaleCount struct {
	metric.Int64Counter
}

ServerFhStaleCount is an instrument used to record metric values conforming to the "nfs.server.fh.stale.count" semantic conventions. It represents the reports the count of kernel NFS server stale file handles.

func NewServerFhStaleCount

func NewServerFhStaleCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerFhStaleCount, error)

NewServerFhStaleCount returns a new ServerFhStaleCount instrument.

func (ServerFhStaleCount) Add

func (m ServerFhStaleCount) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel NFSD_STATS_FH_STALE counter in the nfsd_net struct

func (ServerFhStaleCount) AddSet

func (m ServerFhStaleCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel NFSD_STATS_FH_STALE counter in the nfsd_net struct

func (ServerFhStaleCount) Description

func (ServerFhStaleCount) Description() string

Description returns the semantic convention description of the instrument

func (ServerFhStaleCount) Inst

Inst returns the underlying metric instrument.

func (ServerFhStaleCount) Name

func (ServerFhStaleCount) Name() string

Name returns the semantic convention name of the instrument.

func (ServerFhStaleCount) Unit

func (ServerFhStaleCount) Unit() string

Unit returns the semantic convention unit of the instrument

type ServerIO

type ServerIO struct {
	metric.Int64Counter
}

ServerIO is an instrument used to record metric values conforming to the "nfs.server.io" semantic conventions. It represents the reports the count of kernel NFS server bytes returned to receive and transmit (read and write) requests.

func NewServerIO

func NewServerIO(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerIO, error)

NewServerIO returns a new ServerIO instrument.

func (ServerIO) Add

func (m ServerIO) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

Linux: this metric is taken from the Linux kernel NFSD_STATS_IO_READ and NFSD_STATS_IO_WRITE counters in the nfsd_net struct

func (ServerIO) AddSet

func (m ServerIO) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel NFSD_STATS_IO_READ and NFSD_STATS_IO_WRITE counters in the nfsd_net struct

func (ServerIO) AttrNetworkIODirection

func (ServerIO) AttrNetworkIODirection(val NetworkIODirectionAttr) attribute.KeyValue

AttrNetworkIODirection returns an optional attribute for the "network.io.direction" semantic convention. It represents the network IO operation direction.

func (ServerIO) Description

func (ServerIO) Description() string

Description returns the semantic convention description of the instrument

func (ServerIO) Inst

func (m ServerIO) Inst() metric.Int64Counter

Inst returns the underlying metric instrument.

func (ServerIO) Name

func (ServerIO) Name() string

Name returns the semantic convention name of the instrument.

func (ServerIO) Unit

func (ServerIO) Unit() string

Unit returns the semantic convention unit of the instrument

type ServerNetCount

type ServerNetCount struct {
	metric.Int64Counter
}

ServerNetCount is an instrument used to record metric values conforming to the "nfs.server.net.count" semantic conventions. It represents the reports the count of kernel NFS server TCP segments and UDP datagrams handled.

func NewServerNetCount

func NewServerNetCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerNetCount, error)

NewServerNetCount returns a new ServerNetCount instrument.

func (ServerNetCount) Add

func (m ServerNetCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpcnt and svc_stat.netudpcnt

func (ServerNetCount) AddSet

func (m ServerNetCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpcnt and svc_stat.netudpcnt

func (ServerNetCount) AttrNetworkTransport

func (ServerNetCount) AttrNetworkTransport(val NetworkTransportAttr) attribute.KeyValue

AttrNetworkTransport returns an optional attribute for the "network.transport" semantic convention. It represents the OSI transport layer or inter-process communication method.

func (ServerNetCount) Description

func (ServerNetCount) Description() string

Description returns the semantic convention description of the instrument

func (ServerNetCount) Inst

Inst returns the underlying metric instrument.

func (ServerNetCount) Name

func (ServerNetCount) Name() string

Name returns the semantic convention name of the instrument.

func (ServerNetCount) Unit

func (ServerNetCount) Unit() string

Unit returns the semantic convention unit of the instrument

type ServerNetTCPConnectionAccepted

type ServerNetTCPConnectionAccepted struct {
	metric.Int64Counter
}

ServerNetTCPConnectionAccepted is an instrument used to record metric values conforming to the "nfs.server.net.tcp.connection.accepted" semantic conventions. It represents the reports the count of kernel NFS server TCP connections accepted.

func NewServerNetTCPConnectionAccepted

func NewServerNetTCPConnectionAccepted(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerNetTCPConnectionAccepted, error)

NewServerNetTCPConnectionAccepted returns a new ServerNetTCPConnectionAccepted instrument.

func (ServerNetTCPConnectionAccepted) Add

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpconn

func (ServerNetTCPConnectionAccepted) AddSet

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpconn

func (ServerNetTCPConnectionAccepted) Description

func (ServerNetTCPConnectionAccepted) Description() string

Description returns the semantic convention description of the instrument

func (ServerNetTCPConnectionAccepted) Inst

Inst returns the underlying metric instrument.

func (ServerNetTCPConnectionAccepted) Name

Name returns the semantic convention name of the instrument.

func (ServerNetTCPConnectionAccepted) Unit

Unit returns the semantic convention unit of the instrument

type ServerOperationCount

type ServerOperationCount struct {
	metric.Int64Counter
}

ServerOperationCount is an instrument used to record metric values conforming to the "nfs.server.operation.count" semantic conventions. It represents the reports the count of kernel NFSv4+ server operations.

func NewServerOperationCount

func NewServerOperationCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerOperationCount, error)

NewServerOperationCount returns a new ServerOperationCount instrument.

func (ServerOperationCount) Add

func (m ServerOperationCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

func (ServerOperationCount) AddSet

func (m ServerOperationCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

func (ServerOperationCount) AttrOncRPCVersion

func (ServerOperationCount) AttrOncRPCVersion(val int) attribute.KeyValue

AttrOncRPCVersion returns an optional attribute for the "onc_rpc.version" semantic convention. It represents the ONC/Sun RPC program version.

func (ServerOperationCount) AttrOperationName

func (ServerOperationCount) AttrOperationName(val string) attribute.KeyValue

AttrOperationName returns an optional attribute for the "nfs.operation.name" semantic convention. It represents the NFSv4+ operation name.

func (ServerOperationCount) Description

func (ServerOperationCount) Description() string

Description returns the semantic convention description of the instrument

func (ServerOperationCount) Inst

Inst returns the underlying metric instrument.

func (ServerOperationCount) Name

Name returns the semantic convention name of the instrument.

func (ServerOperationCount) Unit

Unit returns the semantic convention unit of the instrument

type ServerProcedureCount

type ServerProcedureCount struct {
	metric.Int64Counter
}

ServerProcedureCount is an instrument used to record metric values conforming to the "nfs.server.procedure.count" semantic conventions. It represents the reports the count of kernel NFS server procedures.

func NewServerProcedureCount

func NewServerProcedureCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerProcedureCount, error)

NewServerProcedureCount returns a new ServerProcedureCount instrument.

func (ServerProcedureCount) Add

func (m ServerProcedureCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

func (ServerProcedureCount) AddSet

func (m ServerProcedureCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

func (ServerProcedureCount) AttrOncRPCProcedureName

func (ServerProcedureCount) AttrOncRPCProcedureName(val string) attribute.KeyValue

AttrOncRPCProcedureName returns an optional attribute for the "onc_rpc.procedure.name" semantic convention. It represents the ONC/Sun RPC procedure name.

func (ServerProcedureCount) AttrOncRPCVersion

func (ServerProcedureCount) AttrOncRPCVersion(val int) attribute.KeyValue

AttrOncRPCVersion returns an optional attribute for the "onc_rpc.version" semantic convention. It represents the ONC/Sun RPC program version.

func (ServerProcedureCount) Description

func (ServerProcedureCount) Description() string

Description returns the semantic convention description of the instrument

func (ServerProcedureCount) Inst

Inst returns the underlying metric instrument.

func (ServerProcedureCount) Name

Name returns the semantic convention name of the instrument.

func (ServerProcedureCount) Unit

Unit returns the semantic convention unit of the instrument

type ServerRPCCount

type ServerRPCCount struct {
	metric.Int64Counter
}

ServerRPCCount is an instrument used to record metric values conforming to the "nfs.server.rpc.count" semantic conventions. It represents the reports the count of kernel NFS server RPCs handled.

func NewServerRPCCount

func NewServerRPCCount(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerRPCCount, error)

NewServerRPCCount returns a new ServerRPCCount instrument.

func (ServerRPCCount) Add

func (m ServerRPCCount) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

Linux: this metric is taken from the Linux kernel's svc_stat.rpccnt, the count of good RPCs. This metric can have an error.type of "format", "auth", or "client" for svc_stat.badfmt, svc_stat.badauth, and svc_stat.badclnt.

func (ServerRPCCount) AddSet

func (m ServerRPCCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel's svc_stat.rpccnt, the count of good RPCs. This metric can have an error.type of "format", "auth", or "client" for svc_stat.badfmt, svc_stat.badauth, and svc_stat.badclnt.

func (ServerRPCCount) AttrErrorType

func (ServerRPCCount) AttrErrorType(val ErrorTypeAttr) attribute.KeyValue

AttrErrorType returns an optional attribute for the "error.type" semantic convention. It represents the describes a class of error the operation ended with.

func (ServerRPCCount) Description

func (ServerRPCCount) Description() string

Description returns the semantic convention description of the instrument

func (ServerRPCCount) Inst

Inst returns the underlying metric instrument.

func (ServerRPCCount) Name

func (ServerRPCCount) Name() string

Name returns the semantic convention name of the instrument.

func (ServerRPCCount) Unit

func (ServerRPCCount) Unit() string

Unit returns the semantic convention unit of the instrument

type ServerRepcacheRequests

type ServerRepcacheRequests struct {
	metric.Int64Counter
}

ServerRepcacheRequests is an instrument used to record metric values conforming to the "nfs.server.repcache.requests" semantic conventions. It represents the reports the kernel NFS server reply cache request count by cache hit status.

func NewServerRepcacheRequests

func NewServerRepcacheRequests(
	m metric.Meter,
	opt ...metric.Int64CounterOption,
) (ServerRepcacheRequests, error)

NewServerRepcacheRequests returns a new ServerRepcacheRequests instrument.

func (ServerRepcacheRequests) Add

func (m ServerRepcacheRequests) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

func (ServerRepcacheRequests) AddSet

func (m ServerRepcacheRequests) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

func (ServerRepcacheRequests) AttrServerRepcacheStatus

func (ServerRepcacheRequests) AttrServerRepcacheStatus(val string) attribute.KeyValue

AttrServerRepcacheStatus returns an optional attribute for the "nfs.server.repcache.status" semantic convention. It represents the linux: one of "hit" (NFSD_STATS_RC_HITS), "miss" (NFSD_STATS_RC_MISSES), or "nocache" (NFSD_STATS_RC_NOCACHE -- uncacheable).

func (ServerRepcacheRequests) Description

func (ServerRepcacheRequests) Description() string

Description returns the semantic convention description of the instrument

func (ServerRepcacheRequests) Inst

Inst returns the underlying metric instrument.

func (ServerRepcacheRequests) Name

Name returns the semantic convention name of the instrument.

func (ServerRepcacheRequests) Unit

Unit returns the semantic convention unit of the instrument

type ServerThreadCount

type ServerThreadCount struct {
	metric.Int64UpDownCounter
}

ServerThreadCount is an instrument used to record metric values conforming to the "nfs.server.thread.count" semantic conventions. It represents the reports the count of kernel NFS server available threads.

func NewServerThreadCount

func NewServerThreadCount(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ServerThreadCount, error)

NewServerThreadCount returns a new ServerThreadCount instrument.

func (ServerThreadCount) Add

func (m ServerThreadCount) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

Linux: this metric is taken from the Linux kernel nfsd_th_cnt variable

func (ServerThreadCount) AddSet

func (m ServerThreadCount) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

Linux: this metric is taken from the Linux kernel nfsd_th_cnt variable

func (ServerThreadCount) Description

func (ServerThreadCount) Description() string

Description returns the semantic convention description of the instrument

func (ServerThreadCount) Inst

Inst returns the underlying metric instrument.

func (ServerThreadCount) Name

func (ServerThreadCount) Name() string

Name returns the semantic convention name of the instrument.

func (ServerThreadCount) Unit

func (ServerThreadCount) Unit() string

Unit returns the semantic convention unit of the instrument

Source Files

metric.go

Version
v1.43.0 (latest)
Published
Apr 3, 2026
Platform
linux/amd64
Imports
5 packages
Last checked
1 hour ago

Tools for package owners.