package openshiftconv
import "go.opentelemetry.io/otel/semconv/v1.38.0/openshiftconv"
Package openshiftconv provides types and functionality for OpenTelemetry semantic conventions in the "openshift" namespace.
Index ¶
- type ClusterquotaCPULimitHard
- func NewClusterquotaCPULimitHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPULimitHard, error)
- func (m ClusterquotaCPULimitHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaCPULimitHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaCPULimitHard) Description() string
- func (m ClusterquotaCPULimitHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaCPULimitHard) Name() string
- func (ClusterquotaCPULimitHard) Unit() string
- type ClusterquotaCPULimitUsed
- func NewClusterquotaCPULimitUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPULimitUsed, error)
- func (m ClusterquotaCPULimitUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaCPULimitUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaCPULimitUsed) Description() string
- func (m ClusterquotaCPULimitUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaCPULimitUsed) Name() string
- func (ClusterquotaCPULimitUsed) Unit() string
- type ClusterquotaCPURequestHard
- func NewClusterquotaCPURequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPURequestHard, error)
- func (m ClusterquotaCPURequestHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaCPURequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaCPURequestHard) Description() string
- func (m ClusterquotaCPURequestHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaCPURequestHard) Name() string
- func (ClusterquotaCPURequestHard) Unit() string
- type ClusterquotaCPURequestUsed
- func NewClusterquotaCPURequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPURequestUsed, error)
- func (m ClusterquotaCPURequestUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaCPURequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaCPURequestUsed) Description() string
- func (m ClusterquotaCPURequestUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaCPURequestUsed) Name() string
- func (ClusterquotaCPURequestUsed) Unit() string
- type ClusterquotaEphemeralStorageLimitHard
- func NewClusterquotaEphemeralStorageLimitHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageLimitHard, error)
- func (m ClusterquotaEphemeralStorageLimitHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaEphemeralStorageLimitHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaEphemeralStorageLimitHard) Description() string
- func (m ClusterquotaEphemeralStorageLimitHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaEphemeralStorageLimitHard) Name() string
- func (ClusterquotaEphemeralStorageLimitHard) Unit() string
- type ClusterquotaEphemeralStorageLimitUsed
- func NewClusterquotaEphemeralStorageLimitUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageLimitUsed, error)
- func (m ClusterquotaEphemeralStorageLimitUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaEphemeralStorageLimitUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaEphemeralStorageLimitUsed) Description() string
- func (m ClusterquotaEphemeralStorageLimitUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaEphemeralStorageLimitUsed) Name() string
- func (ClusterquotaEphemeralStorageLimitUsed) Unit() string
- type ClusterquotaEphemeralStorageRequestHard
- func NewClusterquotaEphemeralStorageRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageRequestHard, error)
- func (m ClusterquotaEphemeralStorageRequestHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaEphemeralStorageRequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaEphemeralStorageRequestHard) Description() string
- func (m ClusterquotaEphemeralStorageRequestHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaEphemeralStorageRequestHard) Name() string
- func (ClusterquotaEphemeralStorageRequestHard) Unit() string
- type ClusterquotaEphemeralStorageRequestUsed
- func NewClusterquotaEphemeralStorageRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageRequestUsed, error)
- func (m ClusterquotaEphemeralStorageRequestUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaEphemeralStorageRequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaEphemeralStorageRequestUsed) Description() string
- func (m ClusterquotaEphemeralStorageRequestUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaEphemeralStorageRequestUsed) Name() string
- func (ClusterquotaEphemeralStorageRequestUsed) Unit() string
- type ClusterquotaHugepageCountRequestHard
- func NewClusterquotaHugepageCountRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaHugepageCountRequestHard, error)
- func (m ClusterquotaHugepageCountRequestHard) Add( ctx context.Context, incr int64, k8sHugepageSize string, attrs ...attribute.KeyValue, )
- func (m ClusterquotaHugepageCountRequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaHugepageCountRequestHard) Description() string
- func (m ClusterquotaHugepageCountRequestHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaHugepageCountRequestHard) Name() string
- func (ClusterquotaHugepageCountRequestHard) Unit() string
- type ClusterquotaHugepageCountRequestUsed
- func NewClusterquotaHugepageCountRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaHugepageCountRequestUsed, error)
- func (m ClusterquotaHugepageCountRequestUsed) Add( ctx context.Context, incr int64, k8sHugepageSize string, attrs ...attribute.KeyValue, )
- func (m ClusterquotaHugepageCountRequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaHugepageCountRequestUsed) Description() string
- func (m ClusterquotaHugepageCountRequestUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaHugepageCountRequestUsed) Name() string
- func (ClusterquotaHugepageCountRequestUsed) Unit() string
- type ClusterquotaMemoryLimitHard
- func NewClusterquotaMemoryLimitHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryLimitHard, error)
- func (m ClusterquotaMemoryLimitHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaMemoryLimitHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaMemoryLimitHard) Description() string
- func (m ClusterquotaMemoryLimitHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaMemoryLimitHard) Name() string
- func (ClusterquotaMemoryLimitHard) Unit() string
- type ClusterquotaMemoryLimitUsed
- func NewClusterquotaMemoryLimitUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryLimitUsed, error)
- func (m ClusterquotaMemoryLimitUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaMemoryLimitUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaMemoryLimitUsed) Description() string
- func (m ClusterquotaMemoryLimitUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaMemoryLimitUsed) Name() string
- func (ClusterquotaMemoryLimitUsed) Unit() string
- type ClusterquotaMemoryRequestHard
- func NewClusterquotaMemoryRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryRequestHard, error)
- func (m ClusterquotaMemoryRequestHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaMemoryRequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaMemoryRequestHard) Description() string
- func (m ClusterquotaMemoryRequestHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaMemoryRequestHard) Name() string
- func (ClusterquotaMemoryRequestHard) Unit() string
- type ClusterquotaMemoryRequestUsed
- func NewClusterquotaMemoryRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryRequestUsed, error)
- func (m ClusterquotaMemoryRequestUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
- func (m ClusterquotaMemoryRequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaMemoryRequestUsed) Description() string
- func (m ClusterquotaMemoryRequestUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaMemoryRequestUsed) Name() string
- func (ClusterquotaMemoryRequestUsed) Unit() string
- type ClusterquotaObjectCountHard
- func NewClusterquotaObjectCountHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaObjectCountHard, error)
- func (m ClusterquotaObjectCountHard) Add( ctx context.Context, incr int64, k8sResourcequotaResourceName string, attrs ...attribute.KeyValue, )
- func (m ClusterquotaObjectCountHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaObjectCountHard) Description() string
- func (m ClusterquotaObjectCountHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaObjectCountHard) Name() string
- func (ClusterquotaObjectCountHard) Unit() string
- type ClusterquotaObjectCountUsed
- func NewClusterquotaObjectCountUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaObjectCountUsed, error)
- func (m ClusterquotaObjectCountUsed) Add( ctx context.Context, incr int64, k8sResourcequotaResourceName string, attrs ...attribute.KeyValue, )
- func (m ClusterquotaObjectCountUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaObjectCountUsed) Description() string
- func (m ClusterquotaObjectCountUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaObjectCountUsed) Name() string
- func (ClusterquotaObjectCountUsed) Unit() string
- type ClusterquotaPersistentvolumeclaimCountHard
- func NewClusterquotaPersistentvolumeclaimCountHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaPersistentvolumeclaimCountHard, error)
- func (m ClusterquotaPersistentvolumeclaimCountHard) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
- func (m ClusterquotaPersistentvolumeclaimCountHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaPersistentvolumeclaimCountHard) AttrK8SStorageclassName(val string) attribute.KeyValue
- func (ClusterquotaPersistentvolumeclaimCountHard) Description() string
- func (m ClusterquotaPersistentvolumeclaimCountHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaPersistentvolumeclaimCountHard) Name() string
- func (ClusterquotaPersistentvolumeclaimCountHard) Unit() string
- type ClusterquotaPersistentvolumeclaimCountUsed
- func NewClusterquotaPersistentvolumeclaimCountUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaPersistentvolumeclaimCountUsed, error)
- func (m ClusterquotaPersistentvolumeclaimCountUsed) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
- func (m ClusterquotaPersistentvolumeclaimCountUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaPersistentvolumeclaimCountUsed) AttrK8SStorageclassName(val string) attribute.KeyValue
- func (ClusterquotaPersistentvolumeclaimCountUsed) Description() string
- func (m ClusterquotaPersistentvolumeclaimCountUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaPersistentvolumeclaimCountUsed) Name() string
- func (ClusterquotaPersistentvolumeclaimCountUsed) Unit() string
- type ClusterquotaStorageRequestHard
- func NewClusterquotaStorageRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaStorageRequestHard, error)
- func (m ClusterquotaStorageRequestHard) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
- func (m ClusterquotaStorageRequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaStorageRequestHard) AttrK8SStorageclassName(val string) attribute.KeyValue
- func (ClusterquotaStorageRequestHard) Description() string
- func (m ClusterquotaStorageRequestHard) Inst() metric.Int64UpDownCounter
- func (ClusterquotaStorageRequestHard) Name() string
- func (ClusterquotaStorageRequestHard) Unit() string
- type ClusterquotaStorageRequestUsed
- func NewClusterquotaStorageRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaStorageRequestUsed, error)
- func (m ClusterquotaStorageRequestUsed) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
- func (m ClusterquotaStorageRequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
- func (ClusterquotaStorageRequestUsed) AttrK8SStorageclassName(val string) attribute.KeyValue
- func (ClusterquotaStorageRequestUsed) Description() string
- func (m ClusterquotaStorageRequestUsed) Inst() metric.Int64UpDownCounter
- func (ClusterquotaStorageRequestUsed) Name() string
- func (ClusterquotaStorageRequestUsed) Unit() string
Types ¶
type ClusterquotaCPULimitHard ¶
type ClusterquotaCPULimitHard struct {
metric.Int64UpDownCounter
}
ClusterquotaCPULimitHard is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.limit.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaCPULimitHard ¶
func NewClusterquotaCPULimitHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPULimitHard, error)
NewClusterquotaCPULimitHard returns a new ClusterquotaCPULimitHard instrument.
func (ClusterquotaCPULimitHard) Add ¶
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPULimitHard) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPULimitHard) Description ¶
func (ClusterquotaCPULimitHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaCPULimitHard) Inst ¶
func (m ClusterquotaCPULimitHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaCPULimitHard) Name ¶
func (ClusterquotaCPULimitHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaCPULimitHard) Unit ¶
func (ClusterquotaCPULimitHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaCPULimitUsed ¶
type ClusterquotaCPULimitUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaCPULimitUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.limit.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaCPULimitUsed ¶
func NewClusterquotaCPULimitUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPULimitUsed, error)
NewClusterquotaCPULimitUsed returns a new ClusterquotaCPULimitUsed instrument.
func (ClusterquotaCPULimitUsed) Add ¶
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPULimitUsed) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPULimitUsed) Description ¶
func (ClusterquotaCPULimitUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaCPULimitUsed) Inst ¶
func (m ClusterquotaCPULimitUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaCPULimitUsed) Name ¶
func (ClusterquotaCPULimitUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaCPULimitUsed) Unit ¶
func (ClusterquotaCPULimitUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaCPURequestHard ¶
type ClusterquotaCPURequestHard struct {
metric.Int64UpDownCounter
}
ClusterquotaCPURequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaCPURequestHard ¶
func NewClusterquotaCPURequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPURequestHard, error)
NewClusterquotaCPURequestHard returns a new ClusterquotaCPURequestHard instrument.
func (ClusterquotaCPURequestHard) Add ¶
func (m ClusterquotaCPURequestHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPURequestHard) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPURequestHard) Description ¶
func (ClusterquotaCPURequestHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaCPURequestHard) Inst ¶
func (m ClusterquotaCPURequestHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaCPURequestHard) Name ¶
func (ClusterquotaCPURequestHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaCPURequestHard) Unit ¶
func (ClusterquotaCPURequestHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaCPURequestUsed ¶
type ClusterquotaCPURequestUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaCPURequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaCPURequestUsed ¶
func NewClusterquotaCPURequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaCPURequestUsed, error)
NewClusterquotaCPURequestUsed returns a new ClusterquotaCPURequestUsed instrument.
func (ClusterquotaCPURequestUsed) Add ¶
func (m ClusterquotaCPURequestUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPURequestUsed) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaCPURequestUsed) Description ¶
func (ClusterquotaCPURequestUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaCPURequestUsed) Inst ¶
func (m ClusterquotaCPURequestUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaCPURequestUsed) Name ¶
func (ClusterquotaCPURequestUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaCPURequestUsed) Unit ¶
func (ClusterquotaCPURequestUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaEphemeralStorageLimitHard ¶
type ClusterquotaEphemeralStorageLimitHard struct {
metric.Int64UpDownCounter
}
ClusterquotaEphemeralStorageLimitHard is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.limit.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaEphemeralStorageLimitHard ¶
func NewClusterquotaEphemeralStorageLimitHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageLimitHard, error)
NewClusterquotaEphemeralStorageLimitHard returns a new ClusterquotaEphemeralStorageLimitHard instrument.
func (ClusterquotaEphemeralStorageLimitHard) Add ¶
func (m ClusterquotaEphemeralStorageLimitHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageLimitHard) AddSet ¶
func (m ClusterquotaEphemeralStorageLimitHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageLimitHard) Description ¶
func (ClusterquotaEphemeralStorageLimitHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaEphemeralStorageLimitHard) Inst ¶
func (m ClusterquotaEphemeralStorageLimitHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaEphemeralStorageLimitHard) Name ¶
func (ClusterquotaEphemeralStorageLimitHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaEphemeralStorageLimitHard) Unit ¶
func (ClusterquotaEphemeralStorageLimitHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaEphemeralStorageLimitUsed ¶
type ClusterquotaEphemeralStorageLimitUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaEphemeralStorageLimitUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.limit.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaEphemeralStorageLimitUsed ¶
func NewClusterquotaEphemeralStorageLimitUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageLimitUsed, error)
NewClusterquotaEphemeralStorageLimitUsed returns a new ClusterquotaEphemeralStorageLimitUsed instrument.
func (ClusterquotaEphemeralStorageLimitUsed) Add ¶
func (m ClusterquotaEphemeralStorageLimitUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageLimitUsed) AddSet ¶
func (m ClusterquotaEphemeralStorageLimitUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageLimitUsed) Description ¶
func (ClusterquotaEphemeralStorageLimitUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaEphemeralStorageLimitUsed) Inst ¶
func (m ClusterquotaEphemeralStorageLimitUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaEphemeralStorageLimitUsed) Name ¶
func (ClusterquotaEphemeralStorageLimitUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaEphemeralStorageLimitUsed) Unit ¶
func (ClusterquotaEphemeralStorageLimitUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaEphemeralStorageRequestHard ¶
type ClusterquotaEphemeralStorageRequestHard struct {
metric.Int64UpDownCounter
}
ClusterquotaEphemeralStorageRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaEphemeralStorageRequestHard ¶
func NewClusterquotaEphemeralStorageRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageRequestHard, error)
NewClusterquotaEphemeralStorageRequestHard returns a new ClusterquotaEphemeralStorageRequestHard instrument.
func (ClusterquotaEphemeralStorageRequestHard) Add ¶
func (m ClusterquotaEphemeralStorageRequestHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageRequestHard) AddSet ¶
func (m ClusterquotaEphemeralStorageRequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageRequestHard) Description ¶
func (ClusterquotaEphemeralStorageRequestHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaEphemeralStorageRequestHard) Inst ¶
func (m ClusterquotaEphemeralStorageRequestHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaEphemeralStorageRequestHard) Name ¶
func (ClusterquotaEphemeralStorageRequestHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaEphemeralStorageRequestHard) Unit ¶
func (ClusterquotaEphemeralStorageRequestHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaEphemeralStorageRequestUsed ¶
type ClusterquotaEphemeralStorageRequestUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaEphemeralStorageRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaEphemeralStorageRequestUsed ¶
func NewClusterquotaEphemeralStorageRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaEphemeralStorageRequestUsed, error)
NewClusterquotaEphemeralStorageRequestUsed returns a new ClusterquotaEphemeralStorageRequestUsed instrument.
func (ClusterquotaEphemeralStorageRequestUsed) Add ¶
func (m ClusterquotaEphemeralStorageRequestUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageRequestUsed) AddSet ¶
func (m ClusterquotaEphemeralStorageRequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaEphemeralStorageRequestUsed) Description ¶
func (ClusterquotaEphemeralStorageRequestUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaEphemeralStorageRequestUsed) Inst ¶
func (m ClusterquotaEphemeralStorageRequestUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaEphemeralStorageRequestUsed) Name ¶
func (ClusterquotaEphemeralStorageRequestUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaEphemeralStorageRequestUsed) Unit ¶
func (ClusterquotaEphemeralStorageRequestUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaHugepageCountRequestHard ¶
type ClusterquotaHugepageCountRequestHard struct {
metric.Int64UpDownCounter
}
ClusterquotaHugepageCountRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.hugepage_count.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaHugepageCountRequestHard ¶
func NewClusterquotaHugepageCountRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaHugepageCountRequestHard, error)
NewClusterquotaHugepageCountRequestHard returns a new ClusterquotaHugepageCountRequestHard instrument.
func (ClusterquotaHugepageCountRequestHard) Add ¶
func (m ClusterquotaHugepageCountRequestHard) Add( ctx context.Context, incr int64, k8sHugepageSize string, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
The k8sHugepageSize is the the size (identifier) of the K8s huge page.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaHugepageCountRequestHard) AddSet ¶
func (m ClusterquotaHugepageCountRequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaHugepageCountRequestHard) Description ¶
func (ClusterquotaHugepageCountRequestHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaHugepageCountRequestHard) Inst ¶
func (m ClusterquotaHugepageCountRequestHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaHugepageCountRequestHard) Name ¶
func (ClusterquotaHugepageCountRequestHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaHugepageCountRequestHard) Unit ¶
func (ClusterquotaHugepageCountRequestHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaHugepageCountRequestUsed ¶
type ClusterquotaHugepageCountRequestUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaHugepageCountRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.hugepage_count.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaHugepageCountRequestUsed ¶
func NewClusterquotaHugepageCountRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaHugepageCountRequestUsed, error)
NewClusterquotaHugepageCountRequestUsed returns a new ClusterquotaHugepageCountRequestUsed instrument.
func (ClusterquotaHugepageCountRequestUsed) Add ¶
func (m ClusterquotaHugepageCountRequestUsed) Add( ctx context.Context, incr int64, k8sHugepageSize string, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
The k8sHugepageSize is the the size (identifier) of the K8s huge page.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaHugepageCountRequestUsed) AddSet ¶
func (m ClusterquotaHugepageCountRequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaHugepageCountRequestUsed) Description ¶
func (ClusterquotaHugepageCountRequestUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaHugepageCountRequestUsed) Inst ¶
func (m ClusterquotaHugepageCountRequestUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaHugepageCountRequestUsed) Name ¶
func (ClusterquotaHugepageCountRequestUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaHugepageCountRequestUsed) Unit ¶
func (ClusterquotaHugepageCountRequestUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaMemoryLimitHard ¶
type ClusterquotaMemoryLimitHard struct {
metric.Int64UpDownCounter
}
ClusterquotaMemoryLimitHard is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.limit.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaMemoryLimitHard ¶
func NewClusterquotaMemoryLimitHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryLimitHard, error)
NewClusterquotaMemoryLimitHard returns a new ClusterquotaMemoryLimitHard instrument.
func (ClusterquotaMemoryLimitHard) Add ¶
func (m ClusterquotaMemoryLimitHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryLimitHard) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryLimitHard) Description ¶
func (ClusterquotaMemoryLimitHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaMemoryLimitHard) Inst ¶
func (m ClusterquotaMemoryLimitHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaMemoryLimitHard) Name ¶
func (ClusterquotaMemoryLimitHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaMemoryLimitHard) Unit ¶
func (ClusterquotaMemoryLimitHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaMemoryLimitUsed ¶
type ClusterquotaMemoryLimitUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaMemoryLimitUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.limit.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaMemoryLimitUsed ¶
func NewClusterquotaMemoryLimitUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryLimitUsed, error)
NewClusterquotaMemoryLimitUsed returns a new ClusterquotaMemoryLimitUsed instrument.
func (ClusterquotaMemoryLimitUsed) Add ¶
func (m ClusterquotaMemoryLimitUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryLimitUsed) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryLimitUsed) Description ¶
func (ClusterquotaMemoryLimitUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaMemoryLimitUsed) Inst ¶
func (m ClusterquotaMemoryLimitUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaMemoryLimitUsed) Name ¶
func (ClusterquotaMemoryLimitUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaMemoryLimitUsed) Unit ¶
func (ClusterquotaMemoryLimitUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaMemoryRequestHard ¶
type ClusterquotaMemoryRequestHard struct {
metric.Int64UpDownCounter
}
ClusterquotaMemoryRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaMemoryRequestHard ¶
func NewClusterquotaMemoryRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryRequestHard, error)
NewClusterquotaMemoryRequestHard returns a new ClusterquotaMemoryRequestHard instrument.
func (ClusterquotaMemoryRequestHard) Add ¶
func (m ClusterquotaMemoryRequestHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryRequestHard) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryRequestHard) Description ¶
func (ClusterquotaMemoryRequestHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaMemoryRequestHard) Inst ¶
func (m ClusterquotaMemoryRequestHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaMemoryRequestHard) Name ¶
func (ClusterquotaMemoryRequestHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaMemoryRequestHard) Unit ¶
func (ClusterquotaMemoryRequestHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaMemoryRequestUsed ¶
type ClusterquotaMemoryRequestUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaMemoryRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaMemoryRequestUsed ¶
func NewClusterquotaMemoryRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaMemoryRequestUsed, error)
NewClusterquotaMemoryRequestUsed returns a new ClusterquotaMemoryRequestUsed instrument.
func (ClusterquotaMemoryRequestUsed) Add ¶
func (m ClusterquotaMemoryRequestUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)
Add adds incr to the existing count for attrs.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryRequestUsed) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaMemoryRequestUsed) Description ¶
func (ClusterquotaMemoryRequestUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaMemoryRequestUsed) Inst ¶
func (m ClusterquotaMemoryRequestUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaMemoryRequestUsed) Name ¶
func (ClusterquotaMemoryRequestUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaMemoryRequestUsed) Unit ¶
func (ClusterquotaMemoryRequestUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaObjectCountHard ¶
type ClusterquotaObjectCountHard struct {
metric.Int64UpDownCounter
}
ClusterquotaObjectCountHard is an instrument used to record metric values conforming to the "openshift.clusterquota.object_count.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaObjectCountHard ¶
func NewClusterquotaObjectCountHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaObjectCountHard, error)
NewClusterquotaObjectCountHard returns a new ClusterquotaObjectCountHard instrument.
func (ClusterquotaObjectCountHard) Add ¶
func (m ClusterquotaObjectCountHard) Add( ctx context.Context, incr int64, k8sResourcequotaResourceName string, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
The k8sResourcequotaResourceName is the the name of the K8s resource a resource quota defines.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaObjectCountHard) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaObjectCountHard) Description ¶
func (ClusterquotaObjectCountHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaObjectCountHard) Inst ¶
func (m ClusterquotaObjectCountHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaObjectCountHard) Name ¶
func (ClusterquotaObjectCountHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaObjectCountHard) Unit ¶
func (ClusterquotaObjectCountHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaObjectCountUsed ¶
type ClusterquotaObjectCountUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaObjectCountUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.object_count.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaObjectCountUsed ¶
func NewClusterquotaObjectCountUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaObjectCountUsed, error)
NewClusterquotaObjectCountUsed returns a new ClusterquotaObjectCountUsed instrument.
func (ClusterquotaObjectCountUsed) Add ¶
func (m ClusterquotaObjectCountUsed) Add( ctx context.Context, incr int64, k8sResourcequotaResourceName string, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
The k8sResourcequotaResourceName is the the name of the K8s resource a resource quota defines.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaObjectCountUsed) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
func (ClusterquotaObjectCountUsed) Description ¶
func (ClusterquotaObjectCountUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaObjectCountUsed) Inst ¶
func (m ClusterquotaObjectCountUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaObjectCountUsed) Name ¶
func (ClusterquotaObjectCountUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaObjectCountUsed) Unit ¶
func (ClusterquotaObjectCountUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaPersistentvolumeclaimCountHard ¶
type ClusterquotaPersistentvolumeclaimCountHard struct {
metric.Int64UpDownCounter
}
ClusterquotaPersistentvolumeclaimCountHard is an instrument used to record metric values conforming to the "openshift.clusterquota.persistentvolumeclaim_count.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaPersistentvolumeclaimCountHard ¶
func NewClusterquotaPersistentvolumeclaimCountHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaPersistentvolumeclaimCountHard, error)
NewClusterquotaPersistentvolumeclaimCountHard returns a new ClusterquotaPersistentvolumeclaimCountHard instrument.
func (ClusterquotaPersistentvolumeclaimCountHard) Add ¶
func (m ClusterquotaPersistentvolumeclaimCountHard) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
All additional attrs passed are included in the recorded value.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaPersistentvolumeclaimCountHard) AddSet ¶
func (m ClusterquotaPersistentvolumeclaimCountHard) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaPersistentvolumeclaimCountHard) AttrK8SStorageclassName ¶
func (ClusterquotaPersistentvolumeclaimCountHard) AttrK8SStorageclassName(val string) attribute.KeyValue
AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.
func (ClusterquotaPersistentvolumeclaimCountHard) Description ¶
func (ClusterquotaPersistentvolumeclaimCountHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaPersistentvolumeclaimCountHard) Inst ¶
func (m ClusterquotaPersistentvolumeclaimCountHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaPersistentvolumeclaimCountHard) Name ¶
func (ClusterquotaPersistentvolumeclaimCountHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaPersistentvolumeclaimCountHard) Unit ¶
func (ClusterquotaPersistentvolumeclaimCountHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaPersistentvolumeclaimCountUsed ¶
type ClusterquotaPersistentvolumeclaimCountUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaPersistentvolumeclaimCountUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.persistentvolumeclaim_count.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaPersistentvolumeclaimCountUsed ¶
func NewClusterquotaPersistentvolumeclaimCountUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaPersistentvolumeclaimCountUsed, error)
NewClusterquotaPersistentvolumeclaimCountUsed returns a new ClusterquotaPersistentvolumeclaimCountUsed instrument.
func (ClusterquotaPersistentvolumeclaimCountUsed) Add ¶
func (m ClusterquotaPersistentvolumeclaimCountUsed) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
All additional attrs passed are included in the recorded value.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaPersistentvolumeclaimCountUsed) AddSet ¶
func (m ClusterquotaPersistentvolumeclaimCountUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaPersistentvolumeclaimCountUsed) AttrK8SStorageclassName ¶
func (ClusterquotaPersistentvolumeclaimCountUsed) AttrK8SStorageclassName(val string) attribute.KeyValue
AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.
func (ClusterquotaPersistentvolumeclaimCountUsed) Description ¶
func (ClusterquotaPersistentvolumeclaimCountUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaPersistentvolumeclaimCountUsed) Inst ¶
func (m ClusterquotaPersistentvolumeclaimCountUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaPersistentvolumeclaimCountUsed) Name ¶
func (ClusterquotaPersistentvolumeclaimCountUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaPersistentvolumeclaimCountUsed) Unit ¶
func (ClusterquotaPersistentvolumeclaimCountUsed) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaStorageRequestHard ¶
type ClusterquotaStorageRequestHard struct {
metric.Int64UpDownCounter
}
ClusterquotaStorageRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.storage.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.
func NewClusterquotaStorageRequestHard ¶
func NewClusterquotaStorageRequestHard( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaStorageRequestHard, error)
NewClusterquotaStorageRequestHard returns a new ClusterquotaStorageRequestHard instrument.
func (ClusterquotaStorageRequestHard) Add ¶
func (m ClusterquotaStorageRequestHard) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
All additional attrs passed are included in the recorded value.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaStorageRequestHard) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaStorageRequestHard) AttrK8SStorageclassName ¶
func (ClusterquotaStorageRequestHard) AttrK8SStorageclassName(val string) attribute.KeyValue
AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.
func (ClusterquotaStorageRequestHard) Description ¶
func (ClusterquotaStorageRequestHard) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaStorageRequestHard) Inst ¶
func (m ClusterquotaStorageRequestHard) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaStorageRequestHard) Name ¶
func (ClusterquotaStorageRequestHard) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaStorageRequestHard) Unit ¶
func (ClusterquotaStorageRequestHard) Unit() string
Unit returns the semantic convention unit of the instrument
type ClusterquotaStorageRequestUsed ¶
type ClusterquotaStorageRequestUsed struct {
metric.Int64UpDownCounter
}
ClusterquotaStorageRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.storage.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.
func NewClusterquotaStorageRequestUsed ¶
func NewClusterquotaStorageRequestUsed( m metric.Meter, opt ...metric.Int64UpDownCounterOption, ) (ClusterquotaStorageRequestUsed, error)
NewClusterquotaStorageRequestUsed returns a new ClusterquotaStorageRequestUsed instrument.
func (ClusterquotaStorageRequestUsed) Add ¶
func (m ClusterquotaStorageRequestUsed) Add( ctx context.Context, incr int64, attrs ...attribute.KeyValue, )
Add adds incr to the existing count for attrs.
All additional attrs passed are included in the recorded value.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaStorageRequestUsed) AddSet ¶
AddSet adds incr to the existing count for set.
This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.
The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.
func (ClusterquotaStorageRequestUsed) AttrK8SStorageclassName ¶
func (ClusterquotaStorageRequestUsed) AttrK8SStorageclassName(val string) attribute.KeyValue
AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.
func (ClusterquotaStorageRequestUsed) Description ¶
func (ClusterquotaStorageRequestUsed) Description() string
Description returns the semantic convention description of the instrument
func (ClusterquotaStorageRequestUsed) Inst ¶
func (m ClusterquotaStorageRequestUsed) Inst() metric.Int64UpDownCounter
Inst returns the underlying metric instrument.
func (ClusterquotaStorageRequestUsed) Name ¶
func (ClusterquotaStorageRequestUsed) Name() string
Name returns the semantic convention name of the instrument.
func (ClusterquotaStorageRequestUsed) Unit ¶
func (ClusterquotaStorageRequestUsed) Unit() string
Unit returns the semantic convention unit of the instrument
Source Files ¶
metric.go
- Version
- v1.43.0 (latest)
- Published
- Apr 3, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 1 hour ago –
Tools for package owners.