package openshiftconv

import "go.opentelemetry.io/otel/semconv/v1.40.0/openshiftconv"

Package openshiftconv provides types and functionality for OpenTelemetry semantic conventions in the "openshift" namespace.

Index

Types

type ClusterquotaCPULimitHard

type ClusterquotaCPULimitHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaCPULimitHard is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.limit.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaCPULimitHard

func NewClusterquotaCPULimitHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaCPULimitHard, error)

NewClusterquotaCPULimitHard returns a new ClusterquotaCPULimitHard instrument.

func (ClusterquotaCPULimitHard) Add

func (m ClusterquotaCPULimitHard) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPULimitHard) AddSet

func (m ClusterquotaCPULimitHard) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPULimitHard) Description

func (ClusterquotaCPULimitHard) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaCPULimitHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaCPULimitHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaCPULimitHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaCPULimitUsed

type ClusterquotaCPULimitUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaCPULimitUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.limit.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaCPULimitUsed

func NewClusterquotaCPULimitUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaCPULimitUsed, error)

NewClusterquotaCPULimitUsed returns a new ClusterquotaCPULimitUsed instrument.

func (ClusterquotaCPULimitUsed) Add

func (m ClusterquotaCPULimitUsed) Add(ctx context.Context, incr int64, attrs ...attribute.KeyValue)

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPULimitUsed) AddSet

func (m ClusterquotaCPULimitUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPULimitUsed) Description

func (ClusterquotaCPULimitUsed) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaCPULimitUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaCPULimitUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaCPULimitUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaCPURequestHard

type ClusterquotaCPURequestHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaCPURequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaCPURequestHard

func NewClusterquotaCPURequestHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaCPURequestHard, error)

NewClusterquotaCPURequestHard returns a new ClusterquotaCPURequestHard instrument.

func (ClusterquotaCPURequestHard) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPURequestHard) AddSet

func (m ClusterquotaCPURequestHard) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPURequestHard) Description

func (ClusterquotaCPURequestHard) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaCPURequestHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaCPURequestHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaCPURequestHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaCPURequestUsed

type ClusterquotaCPURequestUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaCPURequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.cpu.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaCPURequestUsed

func NewClusterquotaCPURequestUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaCPURequestUsed, error)

NewClusterquotaCPURequestUsed returns a new ClusterquotaCPURequestUsed instrument.

func (ClusterquotaCPURequestUsed) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPURequestUsed) AddSet

func (m ClusterquotaCPURequestUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaCPURequestUsed) Description

func (ClusterquotaCPURequestUsed) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaCPURequestUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaCPURequestUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaCPURequestUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaEphemeralStorageLimitHard

type ClusterquotaEphemeralStorageLimitHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaEphemeralStorageLimitHard is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.limit.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaEphemeralStorageLimitHard

func NewClusterquotaEphemeralStorageLimitHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaEphemeralStorageLimitHard, error)

NewClusterquotaEphemeralStorageLimitHard returns a new ClusterquotaEphemeralStorageLimitHard instrument.

func (ClusterquotaEphemeralStorageLimitHard) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageLimitHard) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageLimitHard) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaEphemeralStorageLimitHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaEphemeralStorageLimitHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaEphemeralStorageLimitHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaEphemeralStorageLimitUsed

type ClusterquotaEphemeralStorageLimitUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaEphemeralStorageLimitUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.limit.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaEphemeralStorageLimitUsed

func NewClusterquotaEphemeralStorageLimitUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaEphemeralStorageLimitUsed, error)

NewClusterquotaEphemeralStorageLimitUsed returns a new ClusterquotaEphemeralStorageLimitUsed instrument.

func (ClusterquotaEphemeralStorageLimitUsed) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageLimitUsed) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageLimitUsed) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaEphemeralStorageLimitUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaEphemeralStorageLimitUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaEphemeralStorageLimitUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaEphemeralStorageRequestHard

type ClusterquotaEphemeralStorageRequestHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaEphemeralStorageRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaEphemeralStorageRequestHard

func NewClusterquotaEphemeralStorageRequestHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaEphemeralStorageRequestHard, error)

NewClusterquotaEphemeralStorageRequestHard returns a new ClusterquotaEphemeralStorageRequestHard instrument.

func (ClusterquotaEphemeralStorageRequestHard) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageRequestHard) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageRequestHard) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaEphemeralStorageRequestHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaEphemeralStorageRequestHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaEphemeralStorageRequestHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaEphemeralStorageRequestUsed

type ClusterquotaEphemeralStorageRequestUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaEphemeralStorageRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.ephemeral_storage.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaEphemeralStorageRequestUsed

func NewClusterquotaEphemeralStorageRequestUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaEphemeralStorageRequestUsed, error)

NewClusterquotaEphemeralStorageRequestUsed returns a new ClusterquotaEphemeralStorageRequestUsed instrument.

func (ClusterquotaEphemeralStorageRequestUsed) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageRequestUsed) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaEphemeralStorageRequestUsed) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaEphemeralStorageRequestUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaEphemeralStorageRequestUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaEphemeralStorageRequestUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaHugepageCountRequestHard

type ClusterquotaHugepageCountRequestHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaHugepageCountRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.hugepage_count.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaHugepageCountRequestHard

func NewClusterquotaHugepageCountRequestHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaHugepageCountRequestHard, error)

NewClusterquotaHugepageCountRequestHard returns a new ClusterquotaHugepageCountRequestHard instrument.

func (ClusterquotaHugepageCountRequestHard) Add

func (m ClusterquotaHugepageCountRequestHard) Add(
	ctx context.Context,
	incr int64,
	k8sHugepageSize string,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

The k8sHugepageSize is the the size (identifier) of the K8s huge page.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaHugepageCountRequestHard) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaHugepageCountRequestHard) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaHugepageCountRequestHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaHugepageCountRequestHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaHugepageCountRequestHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaHugepageCountRequestUsed

type ClusterquotaHugepageCountRequestUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaHugepageCountRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.hugepage_count.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaHugepageCountRequestUsed

func NewClusterquotaHugepageCountRequestUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaHugepageCountRequestUsed, error)

NewClusterquotaHugepageCountRequestUsed returns a new ClusterquotaHugepageCountRequestUsed instrument.

func (ClusterquotaHugepageCountRequestUsed) Add

func (m ClusterquotaHugepageCountRequestUsed) Add(
	ctx context.Context,
	incr int64,
	k8sHugepageSize string,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

The k8sHugepageSize is the the size (identifier) of the K8s huge page.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaHugepageCountRequestUsed) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaHugepageCountRequestUsed) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaHugepageCountRequestUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaHugepageCountRequestUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaHugepageCountRequestUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaMemoryLimitHard

type ClusterquotaMemoryLimitHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaMemoryLimitHard is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.limit.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaMemoryLimitHard

func NewClusterquotaMemoryLimitHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaMemoryLimitHard, error)

NewClusterquotaMemoryLimitHard returns a new ClusterquotaMemoryLimitHard instrument.

func (ClusterquotaMemoryLimitHard) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryLimitHard) AddSet

func (m ClusterquotaMemoryLimitHard) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryLimitHard) Description

func (ClusterquotaMemoryLimitHard) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaMemoryLimitHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaMemoryLimitHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaMemoryLimitHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaMemoryLimitUsed

type ClusterquotaMemoryLimitUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaMemoryLimitUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.limit.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaMemoryLimitUsed

func NewClusterquotaMemoryLimitUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaMemoryLimitUsed, error)

NewClusterquotaMemoryLimitUsed returns a new ClusterquotaMemoryLimitUsed instrument.

func (ClusterquotaMemoryLimitUsed) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryLimitUsed) AddSet

func (m ClusterquotaMemoryLimitUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryLimitUsed) Description

func (ClusterquotaMemoryLimitUsed) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaMemoryLimitUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaMemoryLimitUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaMemoryLimitUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaMemoryRequestHard

type ClusterquotaMemoryRequestHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaMemoryRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaMemoryRequestHard

func NewClusterquotaMemoryRequestHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaMemoryRequestHard, error)

NewClusterquotaMemoryRequestHard returns a new ClusterquotaMemoryRequestHard instrument.

func (ClusterquotaMemoryRequestHard) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryRequestHard) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryRequestHard) Description

func (ClusterquotaMemoryRequestHard) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaMemoryRequestHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaMemoryRequestHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaMemoryRequestHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaMemoryRequestUsed

type ClusterquotaMemoryRequestUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaMemoryRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.memory.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaMemoryRequestUsed

func NewClusterquotaMemoryRequestUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaMemoryRequestUsed, error)

NewClusterquotaMemoryRequestUsed returns a new ClusterquotaMemoryRequestUsed instrument.

func (ClusterquotaMemoryRequestUsed) Add

Add adds incr to the existing count for attrs.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryRequestUsed) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaMemoryRequestUsed) Description

func (ClusterquotaMemoryRequestUsed) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaMemoryRequestUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaMemoryRequestUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaMemoryRequestUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaObjectCountHard

type ClusterquotaObjectCountHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaObjectCountHard is an instrument used to record metric values conforming to the "openshift.clusterquota.object_count.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaObjectCountHard

func NewClusterquotaObjectCountHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaObjectCountHard, error)

NewClusterquotaObjectCountHard returns a new ClusterquotaObjectCountHard instrument.

func (ClusterquotaObjectCountHard) Add

func (m ClusterquotaObjectCountHard) Add(
	ctx context.Context,
	incr int64,
	k8sResourcequotaResourceName string,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

The k8sResourcequotaResourceName is the the name of the K8s resource a resource quota defines.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaObjectCountHard) AddSet

func (m ClusterquotaObjectCountHard) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaObjectCountHard) Description

func (ClusterquotaObjectCountHard) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaObjectCountHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaObjectCountHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaObjectCountHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaObjectCountUsed

type ClusterquotaObjectCountUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaObjectCountUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.object_count.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaObjectCountUsed

func NewClusterquotaObjectCountUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaObjectCountUsed, error)

NewClusterquotaObjectCountUsed returns a new ClusterquotaObjectCountUsed instrument.

func (ClusterquotaObjectCountUsed) Add

func (m ClusterquotaObjectCountUsed) Add(
	ctx context.Context,
	incr int64,
	k8sResourcequotaResourceName string,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

The k8sResourcequotaResourceName is the the name of the K8s resource a resource quota defines.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaObjectCountUsed) AddSet

func (m ClusterquotaObjectCountUsed) AddSet(ctx context.Context, incr int64, set attribute.Set)

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

func (ClusterquotaObjectCountUsed) Description

func (ClusterquotaObjectCountUsed) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaObjectCountUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaObjectCountUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaObjectCountUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaPersistentvolumeclaimCountHard

type ClusterquotaPersistentvolumeclaimCountHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaPersistentvolumeclaimCountHard is an instrument used to record metric values conforming to the "openshift.clusterquota.persistentvolumeclaim_count.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaPersistentvolumeclaimCountHard

func NewClusterquotaPersistentvolumeclaimCountHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaPersistentvolumeclaimCountHard, error)

NewClusterquotaPersistentvolumeclaimCountHard returns a new ClusterquotaPersistentvolumeclaimCountHard instrument.

func (ClusterquotaPersistentvolumeclaimCountHard) Add

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaPersistentvolumeclaimCountHard) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaPersistentvolumeclaimCountHard) AttrK8SStorageclassName

AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.

func (ClusterquotaPersistentvolumeclaimCountHard) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaPersistentvolumeclaimCountHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaPersistentvolumeclaimCountHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaPersistentvolumeclaimCountHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaPersistentvolumeclaimCountUsed

type ClusterquotaPersistentvolumeclaimCountUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaPersistentvolumeclaimCountUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.persistentvolumeclaim_count.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaPersistentvolumeclaimCountUsed

func NewClusterquotaPersistentvolumeclaimCountUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaPersistentvolumeclaimCountUsed, error)

NewClusterquotaPersistentvolumeclaimCountUsed returns a new ClusterquotaPersistentvolumeclaimCountUsed instrument.

func (ClusterquotaPersistentvolumeclaimCountUsed) Add

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaPersistentvolumeclaimCountUsed) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaPersistentvolumeclaimCountUsed) AttrK8SStorageclassName

AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.

func (ClusterquotaPersistentvolumeclaimCountUsed) Description

Description returns the semantic convention description of the instrument

func (ClusterquotaPersistentvolumeclaimCountUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaPersistentvolumeclaimCountUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaPersistentvolumeclaimCountUsed) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaStorageRequestHard

type ClusterquotaStorageRequestHard struct {
	metric.Int64UpDownCounter
}

ClusterquotaStorageRequestHard is an instrument used to record metric values conforming to the "openshift.clusterquota.storage.request.hard" semantic conventions. It represents the enforced hard limit of the resource across all projects.

func NewClusterquotaStorageRequestHard

func NewClusterquotaStorageRequestHard(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaStorageRequestHard, error)

NewClusterquotaStorageRequestHard returns a new ClusterquotaStorageRequestHard instrument.

func (ClusterquotaStorageRequestHard) Add

func (m ClusterquotaStorageRequestHard) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaStorageRequestHard) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Hard` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaStorageRequestHard) AttrK8SStorageclassName

func (ClusterquotaStorageRequestHard) AttrK8SStorageclassName(val string) attribute.KeyValue

AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.

func (ClusterquotaStorageRequestHard) Description

func (ClusterquotaStorageRequestHard) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaStorageRequestHard) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaStorageRequestHard) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaStorageRequestHard) Unit

Unit returns the semantic convention unit of the instrument

type ClusterquotaStorageRequestUsed

type ClusterquotaStorageRequestUsed struct {
	metric.Int64UpDownCounter
}

ClusterquotaStorageRequestUsed is an instrument used to record metric values conforming to the "openshift.clusterquota.storage.request.used" semantic conventions. It represents the current observed total usage of the resource across all projects.

func NewClusterquotaStorageRequestUsed

func NewClusterquotaStorageRequestUsed(
	m metric.Meter,
	opt ...metric.Int64UpDownCounterOption,
) (ClusterquotaStorageRequestUsed, error)

NewClusterquotaStorageRequestUsed returns a new ClusterquotaStorageRequestUsed instrument.

func (ClusterquotaStorageRequestUsed) Add

func (m ClusterquotaStorageRequestUsed) Add(
	ctx context.Context,
	incr int64,
	attrs ...attribute.KeyValue,
)

Add adds incr to the existing count for attrs.

All additional attrs passed are included in the recorded value.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaStorageRequestUsed) AddSet

AddSet adds incr to the existing count for set.

This metric is retrieved from the `Status.Total.Used` field of the K8s ResourceQuotaStatus of the ClusterResourceQuota.

The `k8s.storageclass.name` should be required when a resource quota is defined for a specific storage class.

func (ClusterquotaStorageRequestUsed) AttrK8SStorageclassName

func (ClusterquotaStorageRequestUsed) AttrK8SStorageclassName(val string) attribute.KeyValue

AttrK8SStorageclassName returns an optional attribute for the "k8s.storageclass.name" semantic convention. It represents the name of K8s StorageClass object.

func (ClusterquotaStorageRequestUsed) Description

func (ClusterquotaStorageRequestUsed) Description() string

Description returns the semantic convention description of the instrument

func (ClusterquotaStorageRequestUsed) Inst

Inst returns the underlying metric instrument.

func (ClusterquotaStorageRequestUsed) Name

Name returns the semantic convention name of the instrument.

func (ClusterquotaStorageRequestUsed) Unit

Unit returns the semantic convention unit of the instrument

Source Files

metric.go

Version
v1.43.0 (latest)
Published
Apr 3, 2026
Platform
linux/amd64
Imports
5 packages
Last checked
3 hours ago

Tools for package owners.